pub struct TaxWithheldComponent {
pub tax_collection_model: Option<String>,
pub taxes_withheld: Option<Vec<ChargeComponent>>,
}Expand description
TaxWithheldComponent : Information about the taxes withheld.
Fields
tax_collection_model: Option<String>The tax collection model applied to the item. Possible values: * MarketplaceFacilitator - Tax is withheld and remitted to the taxing authority by Amazon on behalf of the seller. * Standard - Tax is paid to the seller and not remitted to the taxing authority by Amazon.
taxes_withheld: Option<Vec<ChargeComponent>>A list of charge information on the seller’s account.
Implementations
sourceimpl TaxWithheldComponent
impl TaxWithheldComponent
sourcepub fn new() -> TaxWithheldComponent
pub fn new() -> TaxWithheldComponent
Information about the taxes withheld.